function plotHDF( HDF_pathname, bldg_struct )

%   Three-dimensional plotting of pressure tap locations, with wire frame 
%   between building corners. If building dimensions are provided as an
%   optional input argument, then taps can also be plotted with the
%   coordinates scaled to match the building dimensions. The reads
%   Hierarchical Data Format (HDF) pressure database files.
%   The following fields are required in the data file:

%   Tap_Coordinates_3D -- A 5-column matrix with each row defining the 
%       position of one pressure tap:
%       (1) tap #, (2)face #, (3) x-coordinate, (4) y-coord, (5) z-coord
%
%   Building_Corners_3D -- A 3-column matrix with each row defining the 
%       position of one corner of the building: 
%       (1) x-coordinate, (2) y-coord, (3) z-coord
%
%   Wire_Frame_Lines_3D -- A 2-column matrix with each row defining the 
%       numbers of the two building corners to be connected by a line 
%       segment. The corner numbers correspond to the rows of the matrix
%       Building_Corners_3D.

if ~exist('HDF_pathname','var') || isempty(HDF_pathname)
    % Load pathname for HDF files used in last analysis, if available, otherwise create empty string:
    if exist('tmp_HDF_path.mat','file'), load('tmp_HDF_path'); end
    if ~exist('HDF_path','var') || ~isstr(HDF_path), HDF_path = ''; end
    % Prompt user to select pressure database folder:
    HDF_path = uigetdir(HDF_path,'Select the directory containing HDF pressure database files to be displayed');
    if any(HDF_path~=0)
        save('tmp_HDF_path','HDF_path');
        HDF_pathname = HDF_path;
    else
        err = errordlg('HDF pressure database file selection cancelled', 'Analysis cancelled');
        uiwait(err); return;
    end
end

% Obtain list of HDF files in the specified folder:
dir_listing = dir(HDF_pathname);
file_list = dir_listing(find(cat(1,dir_listing.isdir)==0)); % eliminate directories from list
dir_ind = 0; % initialize index for counting the number of wind directions
for i = 1:length(file_list)
    filename = file_list(i).name; 
    hdf_ext_ind = strfind( filename, '.HDF' );
    if ~isempty(hdf_ext_ind)
        dir_ind = dir_ind+1;
        hdf_filename_root{dir_ind} = filename(1:hdf_ext_ind-5);
        theta_a_str(dir_ind,:) = filename(hdf_ext_ind-4:hdf_ext_ind-1);
        theta_a(dir_ind,1) = str2num( theta_a_str(dir_ind,:) )/10;
        theta_a_cell{dir_ind} = [num2str( str2num( theta_a_str(dir_ind,:) )/10 ) ' degrees'];
    end
end
hdf_filename_root = unique(hdf_filename_root);
if size(hdf_filename_root,1)~=1
    err = errordlg(['All HDF file names in the selected directory must be identical '...
        'except for the wind direction, specified by the last 4 characters before the file extension.'], ...
        'Error in pressure database folder contents');
    uiwait(err); return;
end
hdf_filename_root = hdf_filename_root{1};
if isempty( theta_a )
    err = errordlg(['No HDF files found in selected folder'], ...
        'Error in pressure database folder contents');
    uiwait(err); return;
end    

q = 1; % wind direction number

HDF_filename = [hdf_filename_root theta_a_str(q,:) '.HDF'];
HDF_full_filename = fullfile(HDF_pathname, HDF_filename);

HDF_struct = load_hdf_coords( HDF_full_filename );

% Extract sampling frequency (model scale) from HDF data structure:
f_s = HDF_struct.Data_Sample_Rate;

% Extract model dimensions (full-scale) from HDF data structure:
L = HDF_struct.Building_Length_Ft;
W = HDF_struct.Building_Width_Ft;
H = HDF_struct.Building_Height_Ft; % eave height
R = HDF_struct.Roof_Slope_in_12*W/2; % slope is given as rise (in inches) per foot of horizontal distance

tap_c0_3d = HDF_struct.Tap_Coordinates_3D; % tap #, face #, x-coord, y-coord, z-coord

% shift origin to opposite corner of model:
tap_c_3d = tap_c0_3d;
tap_c_3d(:,3) = W-tap_c0_3d(:,3);
tap_c_3d(:,4) = L-tap_c0_3d(:,4);
% eliminate internal pressure taps:
ext_ind = find(tap_c_3d(:,2)~=0);
tap_c_3d = tap_c_3d(ext_ind,:);
% eliminate taps on end walls:
ind_no_ends = intersect(find(tap_c_3d(:,4)~=0), find(tap_c_3d(:,4)~=L));
tap_c_3d = tap_c_3d(ind_no_ends,:);
% assign new face numbers:
tap_c_3d(find(tap_c_3d(:,3)==0),2) = 1;
tap_c_3d(find(tap_c_3d(:,3)>0 & tap_c_3d(:,3)<W/2 ),2) = 2;
tap_c_3d(find(tap_c_3d(:,3)==W/2 ),2) = 0;
tap_c_3d(find(tap_c_3d(:,3)>W/2 & tap_c_3d(:,3)<W),2) = 3;
tap_c_3d(find(tap_c_3d(:,3)==W),2) = 4;

tap_num = tap_c_3d (:,1);
for i=1:length(tap_num)
    tap_num_cell{i} = ['Tap ' num2str(tap_num(i))];
    tap_label_cell{i} = [' ' num2str(tap_num(i))];
end
[tf, tap_ind] = ismember(tap_num, HDF_struct.Tap_Position_List);

tap_circle = [];
tap_label = [];

% error checking (can be removed eventually)
% min(tap_lc(:,1)==tap_trib_bnds(:,1));
if ismember(0, tf)
    error('Tap number not found in "Tap_Position_List" field in HDF file.');
elseif ~isempty(setxor( tap_num, HDF_struct.Tap_Position_List(tap_ind)))
    error('Error in matching tap number with "Tap_Position_List" in HDF file.');
end
tap_sel = 1; % tap number initially selected for plotting


corners = HDF_struct.Building_Corners_3D;
line_ends = HDF_struct.Wire_Frame_Lines_3D;

face_list = unique(tap_c_3d(:,2));
color_list = {'r','b','g','m','c','y','k'};

tap_scale = 0;
if (exist('bldg_struct') && ~isempty(bldg_struct)) && (isfield(bldg_struct,'d0') && ~isempty(bldg_struct.d0))
    tap_scale = 1;
    % Extract structural dimensions from bldg_struct:
    W0 = bldg_struct.d0(1);
    L0 = bldg_struct.d0(2);
    H0 = bldg_struct.d0(3);
    R0 = bldg_struct.d0(4);

    % Scale tap coordinates:
    scl_tap_c_3d = tap_c_3d;
    scl_tap_c_3d(:,3) = scl_tap_c_3d(:,3)*W0/W; % scale x-coordinates
    scl_tap_c_3d(:,4) = scl_tap_c_3d(:,4)*L0/L; % scale y-coordinates
    % scale z-coordinates:
    roof_ind = find(scl_tap_c_3d(:,5)>H);
    wall_ind = find(scl_tap_c_3d(:,5)<=H);
    scl_tap_c_3d(roof_ind,5) = H0+(scl_tap_c_3d(roof_ind,5)-H)*R0/R;
    scl_tap_c_3d(wall_ind,5) = scl_tap_c_3d(wall_ind,5)*H0/H;
    
    % scale building corners:
    scl_corners = corners;
    scl_corners(:,1) = scl_corners(:,1)*W0/W; % scale x-coordinates
    scl_corners(:,2) = scl_corners(:,2)*L0/L; % scale y-coordinates
    % scale z-coordinates:
    roof_crn_ind = find(scl_corners(:,3)>H);
    wall_crn_ind = find(scl_corners(:,3)<=H);
    scl_corners(roof_crn_ind,3) = H0+(scl_corners(roof_crn_ind,3)-H)*R0/R;
    scl_corners(wall_crn_ind,3) = scl_corners(wall_crn_ind,3)*H0/H;
    
end


plot_img = 0;
HDF_fields = fieldnames(HDF_struct);
HDF_img_fields = HDF_fields(find(strncmp(HDF_fields,'Image',5)));
if ~isempty(HDF_img_fields)
    plot_img = 1;
    img_num = 1;
    for i=1:length(HDF_img_fields)
        HDF_img(i).img = HDF_struct.(HDF_img_fields{i});
    end
end

scrsz = get(0,'ScreenSize');
oX = scrsz(3)*.05;
oY = scrsz(4)*.1;
dX = scrsz(3)*.9;
dY = scrsz(4)*.8;
clr = get(0,'DefaultUicontrolBackgroundColor');

top_h = 6; % height of panel at top of figure
btm_h = 5; % height of menu panel at bottom of figure

% ************************* Create figure for plotting tap coordinates:

fig = figure('Color',clr,'Position',[oX oY dX dY],'Name','Plotting of Pressure Tap Coordinates','NumberTitle','off'); 
set( fig, 'Units', 'character');
Size = get( fig, 'Position');
Xc = Size(1);
Yc = Size(2);
X0 = Size(3);
Y0 = Size(4);
plot_h = Y0 - top_h - btm_h;
toggle_w = X0/4-2; % width of toggle buttons on menu panel at bottom
toggle_h = btm_h-1; % height of exit button on menu panel at top

menu_w = 70; % width of menu panel for plot selections at right edge


% create panel for selecting original or scaled tap coordinates:
top_panel = uipanel('Parent',fig,'BackgroundColor',clr,'Units','character','Position',[0 Y0-top_h X0 top_h],...
    'FontSize',12,'FontWeight','bold','TitlePosition','lefttop','Title','Select tap coordinates to plot:');

orig_radio = uicontrol(top_panel, 'Style', 'radiobutton', 'String','Original tap coordinates','Value',1,...
    'Units','characters','Position',[4 top_h-3.5 60 1.5],...
    'Callback',@OrigCallback);
scaled_radio = uicontrol(top_panel, 'Style', 'radiobutton', 'String','Tap coordinates scaled to match building dimensions',...
    'Value',0,'Enable','off','Units','characters','Position',[4 top_h-5 60 1.5],...
    'Callback',@ScaledCallback);
if tap_scale
    set(scaled_radio,'Enable','on');
end

% create panel for selecting taps to label:
tap_label_panel = uipanel('Parent',fig,'BackgroundColor',clr,'Units','character','Position',[X0-menu_w btm_h menu_w plot_h],...
    'FontSize',12,'FontWeight','bold','TitlePosition','lefttop','Title','Select pressure taps to label:');

uicontrol(tap_label_panel,'BackgroundColor',clr, 'Style', 'text', 'String','(ctrl-click or shift-click to select multiple)',...
    'HorizontalAlignment','left','Units','characters','Position',[2 plot_h-4 menu_w-4 1.5]);

tap_label_listbox = uicontrol(tap_label_panel, 'Style', 'listbox', 'String',tap_num_cell,'Value',tap_sel,...
    'Units','characters','Position',[2 plot_h-32 menu_w-4 28],'BackgroundColor','w','Enable','on',...
    'Min',1,'Max',length(tap_num),'Callback',@UpdateTapLabel);

plot_panel = uipanel('Parent',fig,'BackgroundColor',clr,'Units','character','Position',[0 btm_h X0-menu_w plot_h],...
    'FontSize',12,'FontWeight','bold','TitlePosition','lefttop',...
    'Title',['Plot of pressure tap coordinates (filename: ' HDF_filename '):']);
plot_axes = axes('Parent',plot_panel);

menu_panel  = uipanel('Parent',fig,'BackgroundColor',clr,'Units','character','Position',[0 0 X0 btm_h]);

uicontrol(menu_panel, 'Style','pushbutton','String','Photos of Building Model',...
    'Units','characters','Position',[X0/8-toggle_w/2 0.5 toggle_w toggle_h],...
    'Callback',@ImgButtonCallback);

uicontrol(menu_panel, 'Style','togglebutton','String','Pressure Tap Locations','Value',1,'Enable','inactive',...
    'BackgroundColor',.87*[1 1 1],'Units','characters','Position',[X0*3/8-toggle_w/2 0.5 toggle_w toggle_h]);

uicontrol(menu_panel, 'Style','pushbutton','String','Pressure Time Series',...
    'Units','characters','Position',[X0*5/8-toggle_w/2 0.5 toggle_w toggle_h],...
    'Callback',@TSButtonCallback);

uicontrol(menu_panel, 'Style','pushbutton','String','Close',...
    'Units','characters','Position',[X0*7/8-toggle_w/2 0.5 toggle_w toggle_h],...
    'Callback',@ExitCallback);

% ************************* Create figure for displaying photos of model:

img_fig = figure('Color',clr,'Position',[oX oY dX dY],'Name','Plotting of Pressure Tap Coordinates','NumberTitle','off'); 
set( img_fig, 'Units', 'character');

% create panel for selecting frame to plot:
img_select_panel = uipanel('Parent',img_fig,'BackgroundColor',clr,'Units','character','Position',[0 Y0-top_h X0 top_h],...
    'FontSize',12,'FontWeight','bold','TitlePosition','lefttop','Title','Select image to plot:');
img_popup = uicontrol(img_select_panel, 'Style', 'popupmenu', 'String','','Value',img_num,...
    'Units','characters','Position',[2 top_h-4 70 1.5],'BackgroundColor','w','Enable','off',...
    'Callback',@ImgSelectCallback);
if plot_img
    set(img_popup,'String',HDF_img_fields,'Enable','on');
end
    

img_panel = uipanel('Parent',img_fig,'BackgroundColor',clr,'Units','character','Position',[0 btm_h X0 plot_h],...
    'FontSize',12,'FontWeight','bold','TitlePosition','lefttop',...
    'Title',['Photo of building model in the wind tunnel (filename: ' HDF_filename '):']);
img_axes = axes('Parent',img_panel);


img_menu_panel  = uipanel('Parent',img_fig,'BackgroundColor',clr,'Units','character','Position',[0 0 X0 btm_h]);


uicontrol(img_menu_panel, 'Style','togglebutton','String','Photos of Building Model','Value',1,'Enable','inactive',...
    'BackgroundColor',.87*[1 1 1],'Units','characters','Position',[X0/8-toggle_w/2 0.5 toggle_w toggle_h]);

uicontrol(img_menu_panel, 'Style','pushbutton','String','Pressure Tap Locations',...
    'Units','characters','Position',[X0*3/8-toggle_w/2 0.5 toggle_w toggle_h],...
    'Callback',@TapButtonCallback);

uicontrol(img_menu_panel, 'Style','pushbutton','String','Pressure Time Series',...
    'Units','characters','Position',[X0*5/8-toggle_w/2 0.5 toggle_w toggle_h],...
    'Callback',@TSButtonCallback);

uicontrol(img_menu_panel, 'Style','pushbutton','String','Close',...
    'Units','characters','Position',[X0*7/8-toggle_w/2 0.5 toggle_w toggle_h],...
    'Callback',@ExitCallback);

% ************************* Create figure for displaying pressure time series:

ts_fig = figure('Color',clr,'Position',[oX oY dX dY],'Name','Plotting of Pressure Time Series','NumberTitle','off'); 
set( ts_fig, 'Units', 'character');

% create panel for plotting time series:
ts_plot_panel = uipanel('Parent',ts_fig,'BackgroundColor',clr,'Units','character','Position',[0 btm_h X0-menu_w Y0-btm_h],...
    'FontSize',12,'FontWeight','bold','TitlePosition','lefttop',...
    'Title',['Time series of pressure coefficients (filename: ' HDF_filename '):']);
ts_plot_axes = axes('Parent',ts_plot_panel);

% create panel for selecting time series to plot:
ts_select_panel = uipanel('Parent',ts_fig,'BackgroundColor',clr,'Units','character','Position',[X0-menu_w btm_h menu_w Y0-btm_h],...
    'FontSize',12,'FontWeight','bold','TitlePosition','lefttop','Title','Select time series to plot (and save):');

uicontrol(ts_select_panel,'BackgroundColor',clr, 'Style', 'text', 'String','Select wind direction:',...
    'HorizontalAlignment','left','Units','characters','Position',[2 Y0-btm_h-4 menu_w-4 1.5]);

dir_popup = uicontrol(ts_select_panel, 'Style', 'popupmenu', 'String',theta_a_cell,'Value',q,...
    'Units','characters','Position',[2 Y0-btm_h-6 menu_w-4 1.5],'BackgroundColor','w','Enable','on',...
    'Callback',@DirSelectCallback);
    
uicontrol(ts_select_panel,'BackgroundColor',clr, 'Style', 'text', 'String','Select pressure tap numbers:',...
    'HorizontalAlignment','left','Units','characters','Position',[2 Y0-btm_h-9 menu_w-4 1.5]);
uicontrol(ts_select_panel,'BackgroundColor',clr, 'Style', 'text', 'String','(ctrl-click or shift-click to select multiple)',...
    'HorizontalAlignment','left','Units','characters','Position',[2 Y0-btm_h-10 menu_w-4 1.5]);

tap_listbox = uicontrol(ts_select_panel, 'Style', 'listbox', 'String',tap_num_cell,'Value',tap_sel,...
    'Units','characters','Position',[2 Y0-btm_h-38 menu_w-4 28],'BackgroundColor','w','Enable','on',...
    'Min',1,'Max',length(tap_num),'Callback',@UpdateTSPlot);

ts_save_button = uicontrol(ts_select_panel, 'Style','pushbutton','String','Save selected time series...',...
    'Units','characters','Position',[menu_w/2-15 Y0-btm_h-41 30 2],...
    'Callback',@SaveTS);

ts_menu_panel  = uipanel('Parent',ts_fig,'BackgroundColor',clr,'Units','character','Position',[0 0 X0 btm_h]);


uicontrol(ts_menu_panel, 'Style','pushbutton','String','Photos of Building Model',...
    'Units','characters','Position',[X0/8-toggle_w/2 0.5 toggle_w toggle_h],...
    'Callback',@ImgButtonCallback);

uicontrol(ts_menu_panel, 'Style','pushbutton','String','Pressure Tap Locations',...
    'Units','characters','Position',[X0*3/8-toggle_w/2 0.5 toggle_w toggle_h],...
    'Callback',@TapButtonCallback);

uicontrol(ts_menu_panel, 'Style','togglebutton','String','Pressure Time Series','Value',1,'Enable','inactive',...
    'BackgroundColor',.87*[1 1 1],'Units','characters','Position',[X0*5/8-toggle_w/2 0.5 toggle_w toggle_h]);

uicontrol(ts_menu_panel, 'Style','pushbutton','String','Close',...
    'Units','characters','Position',[X0*7/8-toggle_w/2 0.5 toggle_w toggle_h],...
    'Callback',@ExitCallback);


Cp = cpmatrix( HDF_full_filename, tap_ind);

if plot_img
    UpdateImage;
end
UpdatePlot;
UpdateTSPlot;

set(fig,'Visible','off');
set(ts_fig,'Visible','off');
uiwait(img_fig);

function OrigCallback( src, event )
    set( orig_radio, 'Enable', 'inactive');
    set( scaled_radio, 'Value', 0, 'Enable', 'on')
    UpdatePlot;
end
function ScaledCallback( src, event )
    set( scaled_radio, 'Enable', 'inactive');
    set( orig_radio, 'Value',0, 'Enable', 'on');
    UpdatePlot;
end

function UpdatePlot( src, event)
    axes(plot_axes);
    cla reset;
    if get(orig_radio,'Value')
        % plot original tap coordinates:
        plot3(tap_c_3d(:,3),tap_c_3d(:,4),tap_c_3d(:,5),'b.');
        hold on;

        % Plot wire frame between corners of building:
        for i = 1:length(line_ends)
            plot3([corners(line_ends(i,1),1) corners(line_ends(i,2),1)],...
                [corners(line_ends(i,1),2) corners(line_ends(i,2),2)],...
                [corners(line_ends(i,1),3) corners(line_ends(i,2),3)],'k-');
        end
        hold off; 
        xlabel('x-axis'); ylabel('y-axis'); zlabel('z-axis');
        title('Original pressure tap coordinates');
        h = gca;
        set(h, 'DataAspectRatio',[1 1 1],'Projection','perspective');
%        axis equal
        axis vis3d

    elseif get(scaled_radio,'Value')
        % plot scaled tap coordinates:
        plot3(scl_tap_c_3d(:,3),scl_tap_c_3d(:,4),scl_tap_c_3d(:,5),'b.');
        hold on;

        % Plot wire frame between corners of building:
        for i = 1:length(line_ends)
            plot3([scl_corners(line_ends(i,1),1) scl_corners(line_ends(i,2),1)],...
                [scl_corners(line_ends(i,1),2) scl_corners(line_ends(i,2),2)],...
                [scl_corners(line_ends(i,1),3) scl_corners(line_ends(i,2),3)],'k-');
        end
        hold off; 
        xlabel('x-axis'); ylabel('y-axis'); zlabel('z-axis');
        title('Pressure tap coordinates scaled to match building dimensions');
        h = gca;
        set(h, 'DataAspectRatio',[1 1 1],'Projection','perspective');
%        axis equal
        axis vis3d
    end
    UpdateTapLabel;
end    
function UpdateTapLabel( src, event)
    tap_sel = get(tap_label_listbox,'Value');
    axes(plot_axes);
    if ishandle(tap_circle), delete(tap_circle); end
    if ishandle(tap_label), delete(tap_label); end
    hold on;
    if get(orig_radio,'Value')
        tap_circle = plot3(tap_c_3d(tap_sel,3),tap_c_3d(tap_sel,4),tap_c_3d(tap_sel,5),'ro','LineWidth',2);
        tap_label = text(tap_c_3d(tap_sel,3),tap_c_3d(tap_sel,4),tap_c_3d(tap_sel,5),tap_label_cell(tap_sel));
    elseif get(scaled_radio,'Value')
        tap_circle = plot3(scl_tap_c_3d(tap_sel,3),scl_tap_c_3d(tap_sel,4),scl_tap_c_3d(tap_sel,5),'ro','LineWidth',2);
        tap_label = text(scl_tap_c_3d(tap_sel,3),scl_tap_c_3d(tap_sel,4),scl_tap_c_3d(tap_sel,5),tap_label_cell(tap_sel));
    end
    hold off;
end    

function UpdateImage( src, event)
    axes(img_axes);
    cla reset;
    image(HDF_img(img_num).img);
    set(img_axes,'XTickLabel','','YTickLabel','');
end    

function ImgSelectCallback( src, event )
    img_num = get(img_popup,'Value');
    UpdateImage;
end

function DirSelectCallback( src, event )
    q = get(dir_popup,'Value');
    HDF_filename = [hdf_filename_root theta_a_str(q,:) '.HDF'];
    HDF_full_filename = fullfile(HDF_pathname, HDF_filename);
    Cp =  cpmatrix( HDF_full_filename, tap_ind);
    set(ts_plot_panel,'Title',['Time series of pressure coefficients (filename: ' HDF_filename '):']);
    UpdateTSPlot;
end

function UpdateTSPlot( src, event )
    tap_sel = get(tap_listbox,'Value');
    axes(ts_plot_axes);
    cla reset;
    hold on;
    n_s = size(Cp,2); % number of samples
    for i=1:length(tap_sel)
        plot(1:1:n_s,Cp(tap_sel,:));
    end
    hold off;
    legend(tap_num_cell(tap_sel),'Location','EastOutside');
    xlabel('Sample Number');
    ylabel('Pressure coefficient');
end

function SaveTS( src, event )
    TS_filename = ['PR_TS_' HDF_filename(1:end-4) '.csv']; 
    if exist('tmp_TS_path.mat','file'), load('tmp_TS_path'); end
    if ~exist('TS_path','var') || ~isstr(TS_path), TS_path = ''; end
    [TS_filename, TS_path, filetype_ind]= uiputfile({'*.csv','Comma delimited (*.csv)';...
        '*.mat', 'Matlab MAT-files (*.mat)'},'Save time series as', fullfile(TS_path,TS_filename));
    if filetype_ind==0
        figure(fig); return;
    end
    save('tmp_TS_path','TS_path');
    TS_full_filename = fullfile(TS_path, TS_filename);
    V_H = HDF_struct.Reference_Wind_Speed*HDF_struct.Roof_Height_Velocity_Ratio;
    n_s = size(Cp,2); % number of samples
    if filetype_ind==1 
        fw = fopen( TS_full_filename, 'wt');
        if fw==-1
            err = errordlg('Unable to open specified file for writing: make sure that the file is not currently open.',...
                'Error saving time series'); uiwait(err);
            figure(fig); return;
        end
        fprintf( fw, '%s\n',['HDF pressure file: ' HDF_filename]);
        fprintf( fw, '%s\n',['Terrain Conditions: ' HDF_struct.Exposure_Name]);
        fprintf( fw, '%s\n',['Model Length Scale: 1:' num2str(HDF_struct.Building_Scale)]);
        fprintf( fw, '%s\n',['Wind Direction: ' theta_a_cell{q}]);
        fprintf( fw, '%s\n',['Mean Wind Speeed at Eave Height: ' num2str(V_H) ' ft/s']);
        fprintf( fw, '%s\n',['Sampling Frequency: ' num2str(f_s) ' Hz']);
        fprintf( fw, '%s\n',['Number of samples: ' num2str(n_s)]);
        fprintf( fw, '\n');
        fprintf( fw, '%s\n','NOTE: The pressure coefficient time series below are referenced using the mean wind speed at eave height at');
        fprintf( fw, '%s\n','      model scale (given above). An equivalent prototype-scale sampling frequency (which depends on the');
        fprintf( fw, '%s\n','      prototype-scale wind speed of interest) can be obtained by multiplying the model-scale sampling frequency');
        fprintf( fw, '%s\n','      (given above) by (L_M/L_P)*(V_P/V_M) -- where (L_M/L_P) is the model length scale given above; V_M is the');        
        fprintf( fw, '%s\n','      mean wind speed at eave height at model scale (given above); and V_P is the mean wind speed at eave height');
        fprintf( fw, '%s\n','      at prototype scale.');
        fprintf( fw, '\n');
        ts_format = '%g';
        fprintf( fw, '%s','Sample');
        for i=1:length(tap_sel)
            ts_format = [ts_format ',%g'];
            fprintf( fw, ',%s', tap_num_cell{tap_sel(i)});
        end
        ts_format = [ts_format '\n'];
        fprintf( fw, '\n');
        fprintf( fw, ts_format, [1:1:n_s; Cp(tap_sel,:)]);
        status = fclose(fw);
        if status==-1
            err = errordlg('Unable to close specified file after writing.', 'Error saving time series'); uiwait(err);
            figure(fig); return;
        end
    elseif filetype_ind==2
        TS_structure.HDF_filename = HDF_filename;
        TS_structure.terrain = HDF_struct.Exposure_Name;
        TS_structure.length_scale = HDF_struct.Building_Scale;
        TS_structure.length_scale_comment = 'Ratio of full-scale length to model length';
        TS_structure.wind_dir = theta_a(q);
        TS_structure.wind_dir_comment = 'Wind direction in degrees from reference axis';
        TS_structure.V_H = V_H;
        TS_structure.V_H_comment = 'Mean wind speed at eave height in ft/s';
        TS_structure.f_s = f_s;
        TS_structure.f_s_comment = 'Sampling frequency at model scale in Hz';
        TS_structure.n_s = n_s;
        TS_structure.n_s_comment = 'Number of samples in each time series';
        TS_structure.TS_columns = tap_num_cell(tap_sel);
        TS_structure.TS = Cp(tap_sel,:)';
        TS_structure.TS_comment = 'Pressure coefficients referenced using mean wind speed at eave height';
        try
            save(TS_full_filename, 'TS_structure' );
        catch
            msgstr = lasterr;
            err = errordlg(msgstr, 'Error saving time series'); uiwait(err);
            figure(ts_fig); return;
        end
    end
    figure(ts_fig);
end


function TapButtonCallback( src, event )
    if strcmp(get(img_fig, 'Visible'),'on')
        new_pos = get(img_fig,'Position');
        if new_pos(3)<0.9*X0 | new_pos(3)>1.1*X0 | new_pos(4)<0.9*Y0 | new_pos(4)>1.1*Y0
            new_pos = [Xc Yc X0 Y0];
        end
        set( fig, 'Visible','on','Units','characters','Position',new_pos);
        set( img_fig, 'Visible', 'off','Units','characters','Position',new_pos);
    elseif strcmp(get(ts_fig, 'Visible'),'on')
        new_pos = get(ts_fig,'Position');
        if new_pos(3)<0.9*X0 | new_pos(3)>1.1*X0 | new_pos(4)<0.9*Y0 | new_pos(4)>1.1*Y0
            new_pos = [Xc Yc X0 Y0];
        end
        set( fig, 'Visible','on','Units','characters','Position',new_pos);
        set( ts_fig, 'Visible', 'off','Units','characters','Position',new_pos);
        tap_sel = get(tap_listbox,'Value');
        if ~isempty(setxor(tap_sel,get(tap_label_listbox,'Value')))
            set(tap_label_listbox,'Value',tap_sel);
        end
        UpdateTapLabel;
    end
end

function ImgButtonCallback( src, event )
    if strcmp(get(fig, 'Visible'),'on')
        new_pos = get(fig,'Position');
        if new_pos(3)<0.9*X0 | new_pos(3)>1.1*X0 | new_pos(4)<0.9*Y0 | new_pos(4)>1.1*Y0
            new_pos = [Xc Yc X0 Y0];
        end
        set( img_fig, 'Visible','on','Units','characters','Position',new_pos);
        set( fig, 'Visible', 'off','Units','characters','Position',new_pos);
    elseif strcmp(get(ts_fig, 'Visible'),'on')
        new_pos = get(ts_fig,'Position');
        if new_pos(3)<0.9*X0 | new_pos(3)>1.1*X0 | new_pos(4)<0.9*Y0 | new_pos(4)>1.1*Y0
            new_pos = [Xc Yc X0 Y0];
            set(ts_fig,'Position',new_pos);
        end
        set( img_fig, 'Visible','on','Units','characters','Position',new_pos);
        set( ts_fig, 'Visible', 'off','Units','characters','Position',new_pos);
    end
end
function TSButtonCallback( src, event )
    if strcmp(get(fig, 'Visible'),'on')
        new_pos = get(fig,'Position');
        if new_pos(3)<0.9*X0 | new_pos(3)>1.1*X0 | new_pos(4)<0.9*Y0 | new_pos(4)>1.1*Y0
            new_pos = [Xc Yc X0 Y0];
        end
        set( ts_fig, 'Visible','on','Units','characters','Position',new_pos);
        set( fig, 'Visible', 'off','Units','characters','Position',new_pos);
        tap_sel = get(tap_label_listbox,'Value');
        if ~isempty(setxor(tap_sel, get(tap_listbox,'Value')))
            set(tap_listbox,'Value',tap_sel);
        end
        UpdateTSPlot;
    elseif strcmp(get(img_fig, 'Visible'),'on')
        new_pos = get(img_fig,'Position');
        if new_pos(3)<0.9*X0 | new_pos(3)>1.1*X0 | new_pos(4)<0.9*Y0 | new_pos(4)>1.1*Y0
            new_pos = [Xc Yc X0 Y0];
        end
        set( ts_fig, 'Visible','on','Units','characters','Position',new_pos);
        set( img_fig, 'Visible', 'off','Units','characters','Position',new_pos);
    end
end

function ExitCallback( src, event )
    close(ts_fig)
    close(img_fig);
    close(fig);
end

    
    
end